@@ -79,7 +79,7 @@ G_MODULE_EXPORT void on_cad_none_toggled(GtkToggleButton *togglebutton, gpointer
 G_MODULE_EXPORT void on_cad_sort_case_sensitive_toggled(GtkToggleButton *togglebutton, gpointer user_data) {
     gboolean val = gtk_toggle_button_get_active(togglebutton);
     prefs_set_int("cad_case_sensitive", val);
-    gtkpod_broadcast_preference_change("cad_case_sensitive", val);
+    gtkpod_broadcast_preference_change("cad_case_sensitive", &val);
 }
 
 GtkWidget *init_cover_preferences(gchar *gladepath) {
