@@ -26,6 +26,7 @@
 #include <gtk/gtk.h>
 #include <stdlib.h>
 #include <libanjuta/anjuta-plugin-manager.h>
+#include <libanjuta/anjuta-version.h>
 
 #include "anjuta-about.h"
 #include "../libgtkpod/directories.h"
@@ -84,17 +85,22 @@ static gchar* read_documenters(FILE *fp, gchar *line, gint *index, const gchar *
 }
 
 static gchar* read_translators(FILE *fp, gchar *line) {
-    do {
-        line = g_strchomp(line);
-        if (translators == NULL) {
-            translators = g_strdup_printf("%s", line);
-        }
-        else {
-            translators = g_strconcat(translators, "\n", line, NULL);
-        }
+    gboolean found = FALSE;
+    gchar *env_lang = getenv("LANG");
 
+    do {
         if (!(line = about_read_line(fp)))
             return NULL;
+
+        line = g_strchug(line);
+        if (!found && g_str_has_prefix(line, env_lang)) {
+            found = TRUE;
+            gchar *tmp = g_strdup(line + strlen(env_lang));
+            tmp = g_strchug(tmp);
+            translators = g_strconcat("\n\n", tmp, NULL);
+            g_free(tmp);
+        }
+        line = g_strchomp(line);
     }
     while (!g_str_has_suffix(line, ":"));
 
@@ -142,6 +148,7 @@ static void about_free_credit(void) {
         g_free(ptr[i]);
 
     g_free(translators);
+    translators = NULL;
 }
 
 GtkWidget *about_box_new(GtkWindow *parent) {
@@ -189,7 +196,7 @@ GtkWidget *about_box_new(GtkWindow *parent) {
     return dialog;
 }
 
-static void on_about_plugin_activate(GtkMenuItem *item, AnjutaPluginDescription *desc) {
+static void on_about_plugin_activate(GtkMenuItem *item, AnjutaShell *shell) {
     gchar *name = NULL;
     gchar *authors = NULL;
     gchar *license = NULL;
@@ -198,6 +205,9 @@ static void on_about_plugin_activate(GtkMenuItem *item, AnjutaPluginDescription
     gchar *d = NULL;
     GdkPixbuf *pix = NULL;
     GtkWidget *dialog;
+    AnjutaPluginDescription *desc;
+
+    desc = g_object_get_data (G_OBJECT (item), "plugin-desc");
 
     anjuta_plugin_description_get_locale_string(desc, "Anjuta Plugin", "Name", &name);
     anjuta_plugin_description_get_locale_string(desc, "Anjuta Plugin", "Description", &d);
@@ -213,6 +223,8 @@ static void on_about_plugin_activate(GtkMenuItem *item, AnjutaPluginDescription
         authors_v = g_strsplit(authors, ",", -1);
     }
     dialog = gtk_about_dialog_new();
+    gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(shell));
+    gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
     gtk_about_dialog_set_program_name(GTK_ABOUT_DIALOG(dialog), name);
     gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(dialog), VERSION);
     if (license)
@@ -251,7 +263,14 @@ void about_create_plugins_submenu(AnjutaShell *shell, GtkWidget *menuitem) {
     while (node) {
         gchar *label;
         GtkWidget *item;
+
+#if (ANJUTA_CHECK_VERSION(3, 9, 3))
+        AnjutaPluginHandle *handle = (AnjutaPluginHandle *)node->data;
+        AnjutaPluginDescription *desc = anjuta_plugin_handle_get_description (handle);
+#else
         AnjutaPluginDescription *desc = node->data;
+#endif
+
         if (anjuta_plugin_description_get_locale_string(desc, "Anjuta Plugin", "Name", &label)) {
             gchar *authors = NULL;
             gchar *license = NULL;
@@ -259,9 +278,10 @@ void about_create_plugins_submenu(AnjutaShell *shell, GtkWidget *menuitem) {
                     || anjuta_plugin_description_get_string(desc, "Anjuta Plugin", "License", &license)) {
                 item = gtk_menu_item_new_with_label(label);
                 gtk_widget_show(item);
+                g_object_set_data (G_OBJECT (item), "plugin-desc", desc);
                 g_signal_connect (G_OBJECT (item), "activate",
                         G_CALLBACK (on_about_plugin_activate),
-                        desc);
+                        shell);
                 gtk_menu_shell_append(GTK_MENU_SHELL (submenu), item);
                 g_free(authors);
                 g_free(license);
